@@ -1,4 +1,4 @@
 from .fast import Fast, new_path, new_filter
-from .application.futures import HttpRequest, HttpResponse, Filter, MediaFile
+from .application.fast_http import HttpRequest, HttpResponse, Filter, MediaFile
 from .application.annotation import controller, router, post_router, get_router, web_filter
 from .application.annotation import POST, GET
