@@ -1,8 +1,9 @@
 import os
 
 from .setting import Setting
-from ..application.futures import HttpRequest, HttpResponse
+from ..application.fast_http import HttpRequest, HttpResponse
 from ..application.tools import pprint
+from ..application.cookies import Sessions
 
 import traceback
 import inspect
@@ -44,6 +45,7 @@ class Container(Base):
         self.filter = FilterChain()
         self.reject = None
         self.resource = Resource()
+        self.session = Sessions()
 
     def init_mapping(self, setting: Setting):
         """
@@ -122,7 +124,7 @@ class Container(Base):
         :param environ: 请求体
         :return: response
         """
-        request = HttpRequest(environ)
+        request = HttpRequest(environ, self.session)
         response = self.task(request)
         return response
 
@@ -158,6 +160,7 @@ class Container(Base):
                     执行Filter.after()
                     """
                     request, response = self.run_filter_after(request, response)
+                    response.cookie = request.cookie
         except Exception as ex:
             """
             当task执行过程中出现异常时，修改空的response
